helpers

package
v0.0.0-...-bcb6836 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2024 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteEmpty

func DeleteEmpty(s []string) []string

DeleteEmpty returns a slice of strings without empty strings.

func RemoveDuplicateStr

func RemoveDuplicateStr(strSlice []string) []string

RemoveDuplicateStr removes duplicate strings from a slice of strings

func RoundFloat

func RoundFloat(val float64, precision uint) float64

RoundFloat allows for rounding of a float to a given number of decimal places.

Types

This section is empty.

Jump to