nodes

package
v0.0.0-...-6aace5b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: GPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FindVolumeNodes

func FindVolumeNodes(conn *grpc.ClientConn, volumeName string) (volumeNodes []string, errorFound error)

FindVolumeNodes returns a list of nodes that have the given volume

func FormVolumeNodes

func FormVolumeNodes(conn *grpc.ClientConn)

FormVolumeNodes returns a list of nodes that have a volume replica

func GetAllNodesInfo

func GetAllNodesInfo(conn *grpc.ClientConn) (AllNodesInfo []config.NodeInfo, errorFound error)

GetAllNodesInfo returns a list with relevant Node's information

func GetListOfNodes

func GetListOfNodes(conn *grpc.ClientConn) (nodeListReturn map[string][]string, errorFound error)

GetListOfNodes retrieves a list of nodes from the cluster

func GetNodeInfo

func GetNodeInfo(conn *grpc.ClientConn, nodeID string) (nodeInfo config.NodeInfo, errorFound error)

GetNodeInfo returns a Node's information

func GetNodeUsage

func GetNodeUsage(conn *grpc.ClientConn, nodeID string) (nodeUsage int, errorFound error)

func GetReplicasPerNode

func GetReplicasPerNode(conn *grpc.ClientConn, nodeID string) (volumeList map[string]config.VolumeInfo, errorFound error)

GetReplicasPerNode returns a list of volumes that are on the given node

Types

This section is empty.

Jump to