Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteEmpty ¶
DeleteEmpty returns a slice of strings without empty strings.
func RemoveDuplicateStr ¶
RemoveDuplicateStr removes duplicate strings from a slice of strings
func RoundFloat ¶
RoundFloat allows for rounding of a float to a given number of decimal places.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.